@@ -24,17 +24,6 @@ impl Creator {
             is_subscribed: false,
         }
     }
-    fn is_subscribed(&self) -> bool {
-        self.is_subscribed
-    }
-    pub fn subscribe(&mut self) {
-        if self.is_subscribed() {
-            println!("{} user is already subscribed", self.name)
-        } else {
-            println!("{} subsribing user", self.name);
-            self.is_subscribed = true;
-        }
-    }
 }
 
 impl traits::User for Creator {
@@ -42,11 +31,7 @@ impl traits::User for Creator {
         self.name
     }
     fn auth_type(&self) -> &'static str {
-        if self.is_subscribed() {
-            "noooo auth type"
-        } else {
-            "subsribeeeeeed"
-        }
+        "subsribeeeeeed"
     }
 }
 
